==> snortsms-0.14.9.tbz: www/snortsms/rules/act_Save-Update.php <==
<?
/*** We need the rule object handler and functions ***/
include_once("../lib/func_Rules.php");
$rule = New Rule();


$temp_sid = $_REQUEST['FRM_sid'];

/* Get Catagory */
if($_REQUEST['FRM_cat'] != "")
	{
	$temp_cat = $_REQUEST['FRM_cat'];
	}
elseif($_REQUEST['FRM_cat_sel'] != "")
	{
	$temp_cat = $_REQUEST['FRM_cat_sel'];
	}
else
	{
	$temp_cat = "misc";
	}
	
$temp_notes = $_REQUEST['FRM_notes'];


$ruledef = $_REQUEST['FRM_rule'];
?>
<BR><BR>
<CENTER>
<table border="0" class="combo1"><tr><td>
<table border="0" cellspacing="1">
<tr><th colspan="3" class="combo1">Save Rule</th></tr>
<tr class="combo2"><th align="center">Action</th><th>Catagory</th><th>Remarks</th></tr>
<?

/* Cleanup any new lines - if any */
$ruledef = preg_replace("/[\r\n]/sm"," ",$ruledef); 

/*
print "<pre>";
print_r($ruledef);
print "</pre>\n";
*/

/*** Load rule into rule object handler ***/
if($rule->Parse($ruledef))
	{
	//$rule->ShowTree();	

	/*
	// DEBUG
	print "<pre>";
	print_r($_REQUEST);
	print "</pre>\n";
	*/


	/* Check if sid is present - if not generate one in the series range */
	if ( $temp_sid == "" ) 
		{
		$temp_sidseries = $_REQUEST['FRM_sidseries'];		
		$temp_sid = GetNextAvals_sid($temp_sidseries);
		}
	
	/*** Changing sid's are not allowed so restore it  ***/
	$rule->SetOption("sid",$temp_sid);
	
	$ruletext = $rule->GenRule();
	$result = StoreRule($temp_cat,$rule,$temp_notes);
	$status = "Accepted ($result)";
	$color = "Green";


	}
else
	{
	$status = "Rejected";
	$color = "Red";
	$errors = $rule->Get("error");
	$ruletext = "&lt;ERRORS&gt; ";
	foreach($errors as $item) { $ruletext .= " | " . $item; }
	LogEvent("Error: Save rule failed from [".$_SERVER['REMOTE_ADDR']."]");
	}

	
	
$ruletext = htmlspecialchars($ruletext);
$ruletext = wordwrap($ruletext, 100, "<br>",1);
?>
<tr class="bg2"><td nowrap align="center" style="color:<?=$color?>;"><B><?=$status?></B></td><td nowrap align="center"><?=$temp_cat?></td><td><?=$ruletext?></td></tr>
</table>
</td></tr></table>
</CENTER>
<p align="center">
Go to --&gt; 
<a href="index.php?fuseaction=rules.query&FRM_cat=<?=$temp_cat?>">[Rule Category: <?=$temp_cat?>]</a>&nbsp;&nbsp;
<a href="index.php?fuseaction=rules.main">[All Categories]</a>
</p>
<?




$url = "index.php?fuseaction=rules.query&FRM_cat=".$temp_cat;
//header("location:".$url );
//exit(0);

?>

==> snortsms-1.0.0.tbz: www/snortsms/rules/act_Save-Update.php <==
<?
/*** We need the rule object handler and functions ***/
include_once("../lib/func_Rules.php");
$rule = New Rule();


$temp_sid = $_REQUEST['FRM_sid'];

/* Get Catagory */
if($_REQUEST['FRM_cat'] != "")
	{
	$temp_cat = $_REQUEST['FRM_cat'];
	}
elseif($_REQUEST['FRM_cat_sel'] != "")
	{
	$temp_cat = $_REQUEST['FRM_cat_sel'];
	}
else
	{
	$temp_cat = "misc";
	}
	
$temp_notes = $_REQUEST['FRM_notes'];


$ruledef = $_REQUEST['FRM_rule'];
?>
<BR><BR>
<CENTER>
<table border="0" class="combo1"><tr><td>
<table border="0" cellspacing="1">
<tr><th colspan="3" class="combo1">Save Rule</th></tr>
<tr class="combo2"><th align="center">Action</th><th>Catagory</th><th>Remarks</th></tr>
<?

/* Cleanup any new lines - if any */
$ruledef = preg_replace("/[\r\n]/sm"," ",$ruledef); 

/*
print "<pre>";
print_r($ruledef);
print "</pre>\n";
*/

/*** Load rule into rule object handler ***/
if($rule->Parse($ruledef))
	{
	//$rule->ShowTree();	

/*
	// DEBUG
	print "<pre>";
	print_r($_REQUEST);
	print "</pre>\n";

	print"SID: " . $rule->GetOption("sid");
*/

/* Check if sid is present - if not generate one in the series range */
if($rule->GetOption("sid") != "")
	{
	/* do nothing - sid already set */
	}
elseif ( $temp_sid == "" ) 
	{
	$temp_sidseries = $_REQUEST['FRM_sidseries'];		
	$temp_sid = GetNextAvals_sid($temp_sidseries);
	/*** Changing sid's are not allowed so restore it  ***/
	$rule->SetOption("sid",$temp_sid);
	}
	
	
	$ruletext = $rule->GenRule();
	$result = StoreRule($temp_cat,$rule,$temp_notes);
	$status = "Accepted ($result)";
	$color = "Green";


	}
else
	{
	$status = "Rejected";
	$color = "Red";
	$errors = $rule->Get("error");
	$ruletext = "&lt;ERRORS&gt; ";
	foreach($errors as $item) { $ruletext .= " | " . $item; }
	LogEvent("Error: Save rule failed from [".$_SERVER['REMOTE_ADDR']."]");
	}

	
	
$ruletext = htmlspecialchars($ruletext);
$ruletext = wordwrap($ruletext, 100, "<br>",1);
?>
<tr class="bg2"><td nowrap align="center" style="color:<?=$color?>;"><B><?=$status?></B></td><td nowrap align="center"><?=$temp_cat?></td><td><?=$ruletext?></td></tr>
</table>
</td></tr></table>
</CENTER>
<p align="center">
Go to --&gt; 
<a href="index.php?fuseaction=rules.query&FRM_cat=<?=$temp_cat?>">[Rule Category: <?=$temp_cat?>]</a>&nbsp;&nbsp;
<a href="index.php?fuseaction=rules.main">[All Categories]</a>
</p>
<?




$url = "index.php?fuseaction=rules.query&FRM_cat=".$temp_cat;
//header("location:".$url );
//exit(0);

?>
